.wrapper {
    display: block;
    overflow: hidden;
    position: relative;
    width: 100%
}

.wrapper .container {
    max-width: 80rem
}

.wrapper > .container {
    padding-bottom: 7.5rem;
    padding-top: 7.5rem
}

.header {
    background-color: #f4f5f6;
    padding-top: 1rem
}

@media (min-width: 40rem) {
    .header {
        padding-top: 5rem
    }
}

.header + section {
    border-top: 0
}

.header .container {
    border-top: 0;
    padding-bottom: 7.5rem;
    padding-top: 7.5rem;
    position: relative;
    text-align: center
}

.header .title {
    font-family: Gotham Rounded A, Gotham Rounded B, Helvetica Neue, Arial, sans-serif
}

.header .img {
    height: 15rem;
    margin-bottom: 2rem
}

.header .button {
    margin-bottom: 4rem;
    margin-top: 2rem
}

@media (min-width: 40rem) {
    .header .button {
        margin-bottom: 4rem;
        margin-top: 2rem
    }
}

.navigation {
    background: #f4f5f6;
    border-bottom: .1rem solid #d1d1d1;
    display: block;
    height: 5.2rem;
    left: 0;
    max-width: 100%;
    position: fixed;
    right: 0;
    top: 0;
    width: 100%;
    z-index: 1
}

.navigation .container {
    padding-bottom: 0;
    padding-top: 0
}

.navigation .navigation-list {
    list-style: none;
    margin-bottom: 0;
    margin-right: 5rem
}

@media (min-width: 80rem) {
    .navigation .navigation-list {
        margin-right: 0
    }
}

.navigation .navigation-item {
    float: left;
    margin-bottom: 0;
    margin-left: 2.5rem;
    position: relative
}

.navigation .img {
    height: 2rem;
    position: relative;
    top: .3rem
}

.navigation .navigation-title, .navigation .title {
    color: #606c76;
    font-family: Gotham Rounded A, Gotham Rounded B, Helvetica Neue, Arial, sans-serif;
    position: relative
}

.navigation .navigation-link, .navigation .navigation-title, .navigation .title {
    display: inline;
    font-size: 1.6rem;
    line-height: 5.2rem;
    padding: 0;
    text-decoration: none
}

.navigation .navigation-link.active {
    color: #606c76
}

.github {
    border: 0;
    color: #f4f5f6;
    fill: #9b4dca;
    height: 5.2rem;
    position: fixed;
    right: 0;
    top: 0;
    width: 5.2rem;
    z-index: 1
}

.github:hover .octo-arm {
    animation: a .56s infinite
}

@keyframes a {
    0%, 50% {
        transform: rotate(0)
    }
    25%, 75% {
        transform: rotate(-25deg)
    }
}

.popover {
    background: #fff;
    border: .1rem solid #d1d1d1;
    border-radius: .4rem;
    display: none;
    filter: drop-shadow(0 0 .6rem rgba(0, 0, 0, .1));
    left: 50%;
    min-width: 13.4rem;
    position: absolute;
    top: 94%;
    transform: translateX(-50%)
}

.popover.popover-open {
    display: block
}

.popover:after, .popover:before {
    border: solid transparent;
    border-color: transparent;
    border-width: 1rem;
    content: ' ';
    height: 0;
    left: 50%;
    pointer-events: none;
    position: absolute;
    right: 1.7rem;
    top: 0;
    width: 0
}

.popover:after {
    border-bottom-color: #fff;
    transform: translate(-50%, -100%)
}

.popover:before {
    border-bottom-color: #d1d1d1;
    transform: translate(-50%, -102%)
}

.popover .popover-list {
    list-style: none;
    margin: 0;
    padding: 0
}

.popover .popover-item {
    margin: 0;
    padding: 0
}

.popover .popover-item:first-child .popover-link {
    border-radius: .4rem .4rem 0 0
}

.popover .popover-item:last-child .popover-link {
    border-bottom-width: 0;
    border-radius: 0 0 .4rem .4rem
}

.popover .popover-link {
    border-bottom: .1rem solid #d1d1d1;
    color: #606c76;
    display: block;
    font-size: 1.2rem;
    padding: .8rem 2rem;
    position: relative;
    text-align: center;
    text-decoration: none
}

.popover .popover-link:hover {
    background: #9b4dca;
    border-bottom-color: #9b4dca;
    color: #fff
}

.share, .share-list, .share-list a {
    position: relative;
    text-decoration: none
}

.share-item {
    display: inline-block;
    margin: 1rem .1rem
}

.share-dialog {
    background-color: #9b4dca;
    border-radius: .4rem;
    color: #fff;
    display: block;
    height: 2.2rem;
    text-align: center;
    width: 5rem
}

.share-dialog:hover {
    background-color: #606c76
}

.share-dialog .share-icon {
    fill: #fff;
    height: 1.5rem
}

@media (min-width: 40rem) {
    .only-mobile {
        display: none
    }
}

.prettyprint.code {
    border: 0;
    border-left: .3rem solid #9b4dca;
    color: #655d5d
}

.prettyprint.code .str {
    color: #4b8b8b
}

.prettyprint.code .kwd {
    color: #8464c4
}

.prettyprint.code .com {
    color: #adadad
}

.prettyprint.code .typ {
    color: #7272ca
}

.prettyprint.code .lit {
    color: #9b4dca
}

.prettyprint.code .pun {
    color: #5485b6
}

.prettyprint.code .clo, .prettyprint.code .opn {
    color: #f4ecec
}

.prettyprint.code .atn, .prettyprint.code .tag {
    color: #9b4dca
}

.prettyprint.code .atv {
    color: #5485b6
}

.prettyprint.code .dec {
    color: #b45a3c
}

.prettyprint.code .var {
    color: #ca4949
}

.prettyprint.code .fun {
    color: #7272ca
}

.prettyprint.code.lang-md * {
    color: #655d5d
}

.carbonads {
    background-color: #f4f5f6;
    border-radius: 4px;
    color: #606c76;
    display: block;
    line-height: 1.6;
    margin: 0 auto;
    margin-bottom: 2rem;
    max-width: 33rem;
    overflow: hidden;
    padding: 1.5rem
}

.carbonads.carbonads-home {
    background-color: #fff;
    margin-bottom: 0
}

.carbonads span {
    display: block;
    overflow: hidden
}

.carbonads .carbon-poweredby, .carbonads .carbon-text {
    color: #606c76;
    display: block;
    float: right;
    font-size: 1.2rem;
    max-width: 44%;
    text-align: left;
    width: 44%
}

@media (min-width: 40rem) {
    .carbonads .carbon-poweredby, .carbonads .carbon-text {
        max-width: 52%;
        width: 52%
    }
}

.carbonads .carbon-poweredby {
    margin: 0;
    margin-top: -2.5rem
}

.carbonads .carbon-img {
    float: left;
    margin-right: 1rem
}

.example {
    margin-top: 4rem;
    position: relative
}

.example .example-header {
    font-weight: 600;
    margin-bottom: .5rem;
    margin-top: 1.5rem
}

.example .column-demo {
    background: #d1d1d1;
    border-radius: .4rem;
    display: block;
    font-size: 1rem;
    font-weight: 600;
    height: 3rem;
    letter-spacing: .1rem;
    line-height: 3rem;
    margin-bottom: 2.5rem;
    text-align: center;
    text-transform: uppercase
}

.example.row, .example .row {
    margin-bottom: 0
}

.example h1, .example h2, .example h3, .example h4, .example h5, .example h6 {
    margin-bottom: 1rem
}

.example .heading-font-size {
    color: #999;
    font-size: 1.2rem;
    letter-spacing: normal
}

.example form {
    margin-bottom: 0
}

.button-black {
    background-color: #000;
    border-color: #000
}

.button-black.button-clear, .button-black.button-outline {
    color: #000
}

.button-large {
    font-size: 1.4rem;
    height: 4.5rem;
    line-height: 4.5rem;
    padding: 0 2rem
}

.button-small {
    font-size: .8rem;
    height: 2.8rem;
    line-height: 2.8rem;
    padding: 0 1.5rem
}